@@ -1,4 +1,6 @@
 from scapy_helper.main import get_hex, show_diff, show_hex, table, hex_equal
+from scapy_helper.hexdump import hexdump
+from scapy_helper.chexdump import chexdump
 from scapy_helper.compare import Compare
 
 from scapy_helper.test_case_extensions.packet_assert import PacketAssert
